﻿$URL = "PATH"
$ErrorActionPreference ="Stop"
$PSDefaultParameterValues['*:ErrorAction']='Stop'

#First time tasks
#Install-Module SharePointPnPPowerShellOnline 
#$Creds = get-credential
#Add-PnPStoredCredential -Name $URL -Username $Creds.UserName -Password $Creds.Password

import-Module SharePointPnPPowerShellOnline 
Connect-PnPOnline $URL 

function Create-MyApp([string] $ListName, [string] $ListURL,[Microsoft.SharePoint.Client.ListTemplateType] $AppType){
    #Always versioning on
    if($ListURL -eq ""){
        $ListURL =$ListName.Replace(" ","").ToLower()
    }
    New-PnPList -Title $ListName -Template $AppType -EnableVersioning -OnQuickLaunch -Url $ListURL
    Write-Host ($AppType.ToString() + " " + $ListName + " has been created!") -ForegroundColor Green    
}

$Departments = "Sales","Production", "Support"

foreach($Dep in $Departments){
    #Create the subsite
    Write-Host ("Creating sub site " + $Dep + " ...") -ForegroundColor Yellow
    New-PnPWeb -Title $Dep -Url $Dep -InheritNavigation -Template SITEPAGEPUBLISHING#0


    #Add navigation node to the top site
    Add-PnPNavigationNode -Location QuickLaunch -Title $Dep -Url ($URL + "/" + $Dep)
    Write-Host ("Done with site " + $Dep + " ...") -ForegroundColor Green
}


function Add-Themes(){
    $SalesTheme = @{
"themePrimary" = "#7bd400";
"themeLighterAlt" = "#f9fdf3";
"themeLighter" = "#e8f8d0";
"themeLight" = "#d4f2a9";
"themeTertiary" = "#ace55c";
"themeSecondary" = "#89d91a";
"themeDarkAlt" = "#6fbe00";
"themeDark" = "#5ea100";
"themeDarker" = "#457700";
"neutralLighterAlt" = "#f8f8f8";
"neutralLighter" = "#f4f4f4";
"neutralLight" = "#eaeaea";
"neutralQuaternaryAlt" = "#dadada";
"neutralQuaternary" = "#d0d0d0";
"neutralTertiaryAlt" = "#c8c8c8";
"neutralTertiary" = "#bab8b7";
"neutralSecondary" = "#a3a2a0";
"neutralPrimaryAlt" = "#8d8b8a";
"neutralPrimary" = "#323130";
"neutralDark" = "#605e5d";
"black" = "#494847";
"white" = "#ffffff";
}
    Add-PnPTenantTheme -Identity "Sales" -Palette $SalesTheme -IsInverted $false

    $SupportTheme = @{
"themePrimary" = "#d42300";
"themeLighterAlt" = "#fdf5f3";
"themeLighter" = "#f8d7d0";
"themeLight" = "#f2b5a9";
"themeTertiary" = "#e5725c";
"themeSecondary" = "#d93a1a";
"themeDarkAlt" = "#be2000";
"themeDark" = "#a11b00";
"themeDarker" = "#771400";
"neutralLighterAlt" = "#f8f8f8";
"neutralLighter" = "#f4f4f4";
"neutralLight" = "#eaeaea";
"neutralQuaternaryAlt" = "#dadada";
"neutralQuaternary" = "#d0d0d0";
"neutralTertiaryAlt" = "#c8c8c8";
"neutralTertiary" = "#bab8b7";
"neutralSecondary" = "#a3a2a0";
"neutralPrimaryAlt" = "#8d8b8a";
"neutralPrimary" = "#323130";
"neutralDark" = "#605e5d";
"black" = "#494847";
"white" = "#ffffff";
}
    Add-PnPTenantTheme -Identity "Support" -Palette $SupportTheme -IsInverted $false


    $ProductionTheme = @{
"themePrimary" = "#d48300";
"themeLighterAlt" = "#fdf9f3";
"themeLighter" = "#f8e9d0";
"themeLight" = "#f2d6a9";
"themeTertiary" = "#e5b05c";
"themeSecondary" = "#d9901a";
"themeDarkAlt" = "#be7500";
"themeDark" = "#a16300";
"themeDarker" = "#774900";
"neutralLighterAlt" = "#f8f8f8";
"neutralLighter" = "#f4f4f4";
"neutralLight" = "#eaeaea";
"neutralQuaternaryAlt" = "#dadada";
"neutralQuaternary" = "#d0d0d0";
"neutralTertiaryAlt" = "#c8c8c8";
"neutralTertiary" = "#bab8b7";
"neutralSecondary" = "#a3a2a0";
"neutralPrimaryAlt" = "#8d8b8a";
"neutralPrimary" = "#323130";
"neutralDark" = "#605e5d";
"black" = "#494847";
"white" = "#ffffff";
}
    Add-PnPTenantTheme -Identity "Production" -Palette $ProductionTheme -IsInverted $false
    Write-Host "Themes added" -ForegroundColor Green
}
Add-Themes

function Add-Apps(){
    #Add apps
    Write-Host "Creating apps ... " -ForegroundColor Yellow
    Create-MyApp -ListName "Photos" -AppType PictureLibrary
    Create-MyApp -ListName "Tasks" -AppType Tasks
}

function Add-SubsiteNavigation(){
    foreach($DepSub in $Departments){
        if($Dep -ne $DepSub){
            Add-PnPNavigationNode -Location QuickLaunch -Title $DepSub -Url ($URL + "/" + $DepSub)
        }
    }
    Add-PnPNavigationNode -Location QuickLaunch -Title "HQ" -Url $URL
    Add-PnPNavigationNode -Location QuickLaunch -Title "Pedalling" -Url "https://pedalling.com" -External

}

function Add-Pages(){
    Add-PnPClientSidePage -Name "Progress"
    Add-PnPClientSidePage -Name "Problems"
    Add-PnPClientSidePage -Name "Plans"
}

foreach($Dep in $Departments){
    $CurrWebURL =($URL + "/" + $Dep)
    #Connect to the department site
    Write-Host ("Fixing " + $CurrWebURL  + " ... ") -ForegroundColor Yellow
    Connect-PnPOnline $CurrWebURL 
    Add-Apps
    Add-SubsiteNavigation
    Add-Pages
    Set-PnPWebTheme -Theme $Dep
    Write-Host ("Done with " + $CurrWebURL ) -ForegroundColor Green
}

#Connect back to the root site
Start-Sleep -Seconds 5
Connect-PnPOnline $URL 
Add-PnPNavigationNode -Location QuickLaunch -Title "Pedalling" -Url "https://pedalling.com" -External

function Remove-All(){
    Connect-PnPOnline $URL 
    foreach($Dep in $Departments){
        Write-Host ("Removing subsite " + $Dep + " ... ") -ForegroundColor Red
        Remove-PnPWeb -Url $Dep -Force
        Remove-PnPTenantTheme -Identity $Dep
    }

    $AllNodes = Get-PnPNavigationNode -Location QuickLaunch
    foreach($Node in $AllNodes){
        #$Node = $AllNodes[0]
        if($Node.Title -eq "Pedalling"){
            Remove-PnPNavigationNode  -Identity $Node.Id -Force
        }
    }
    Write-Host ("Everything removed") -ForegroundColor Green
}
